@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 __author__ = "Vanessa Sochat"
-__copyright__ = "Copyright 2021-2023, Vanessa Sochat"
+__copyright__ = "Copyright 2021-2022, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
 import argparse
@@ -11,8 +11,6 @@ import sys
 import shpc
 from shpc.logger import setup_logger
 
-from . import help
-
 
 def get_parser():
     parser = argparse.ArgumentParser(
@@ -47,7 +45,10 @@ def get_parser():
     parser.add_argument(
         "-c",
         dest="config_params",
-        help=help.config_params,
+        help=""""customize a config value on the fly to ADD/SET/REMOVE for a command
+shpc -c set:key:value <command> <args>
+shpc -c add:registry:/tmp/registry <command> <args>
+shpc -c rm:registry:/tmp/registry""",
         action="append",
     )
 
@@ -73,12 +74,12 @@ def get_parser():
     # Local shell with client loaded
     shell = subparsers.add_parser(
         "shell",
-        description=help.shell_description,
+        description="shell into a Python session with a client.",
         formatter_class=argparse.RawTextHelpFormatter,
     )
     shell.add_argument(
         "module_name",
-        help="optionally provide the container module name to shell into, with loaded.",
+        help="shell into an interactive session.\nshpc shell python (shell into a container)\nshpc shell (python interactive shell)",
         nargs="?",
     )
     shell.add_argument(
@@ -93,24 +94,13 @@ def get_parser():
     # Install a known recipe from the registry
     install = subparsers.add_parser(
         "install",
-        description=help.install_description,
+        description="install a registry recipe.",
         formatter_class=argparse.RawTextHelpFormatter,
     )
-    install.add_argument("install_recipe", help="recipe to install")
-
     install.add_argument(
-        "container_image",
-        help="path to an existing container image for this software",
-        nargs="?",
+        "install_recipe",
+        help="recipe to install\nshpc install python\nshpc install python:3.9.5-alpine",
     )
-
-    install.add_argument(
-        "--keep-path",
-        help="if installing a local container, do not copy the container - use the provided path.",
-        default=False,
-        action="store_true",
-    )
-
     install.add_argument(
         "--no-view",
         dest="no_view",
@@ -127,11 +117,7 @@ def get_parser():
     )
 
     # List installed modules
-    listing = subparsers.add_parser(
-        "list",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.listing_description,
-    )
+    listing = subparsers.add_parser("list", description="list installed modules.")
     listing.add_argument("pattern", help="filter to a pattern", nargs="?")
     listing.add_argument(
         "--names-only", help="omit versions", default=False, action="store_true"
@@ -146,9 +132,7 @@ def get_parser():
 
     # List local containers and collections
     inspect = subparsers.add_parser(
-        "inspect",
-        description=help.inspect_description,
-        formatter_class=argparse.RawTextHelpFormatter,
+        "inspect", description="inspect an installed module image."
     )
     inspect.add_argument("module_name", help="module to inspect")
     inspect.add_argument(
@@ -159,11 +143,7 @@ def get_parser():
     )
 
     # Get path to an image
-    get = subparsers.add_parser(
-        "get",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.get_description,
-    )
+    get = subparsers.add_parser("get", description="get an image path for a module")
     get.add_argument("module_name", help="the name of the module")
     get.add_argument(
         "-e",
@@ -174,11 +154,7 @@ def get_parser():
     )
 
     # Add a container direcly
-    add = subparsers.add_parser(
-        "add",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.add_description,
-    )
+    add = subparsers.add_parser("add", description="add an image to modules manually")
     add.add_argument("container_uri", help="full path to container image file")
     add.add_argument(
         "module_id",
@@ -186,29 +162,29 @@ def get_parser():
         nargs="?",
     )
 
-    # Remove a container recipe
-    remove = subparsers.add_parser(
-        "remove", description="remove a container.yaml entry"
-    )
-    remove.add_argument(
-        "module_id",
-        help='desired identifier path to remove (e.g. "quay.io/biocontainers"). Leave out to remove all.',
-        nargs="?",
-    )
-
     check = subparsers.add_parser(
-        "check",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.check_description,
+        "check", description="check if you have latest installed."
     )
     check.add_argument("module_name", help="module to check (module:version)")
 
     view = subparsers.add_parser(
         "view",
-        description=help.view_description,
+        description="view control to create, install, and uninstall",
         formatter_class=argparse.RawTextHelpFormatter,
     )
-    view.add_argument("params", nargs="*", type=str, help="parameters for view command")
+    view.add_argument(
+        "params",
+        nargs="*",
+        help="""View control. A view name is always required.
+shpc view create <name>
+shpc view delete <name>
+shpc view get <name>
+shpc view list <name>
+shpc view install <name> <module>
+shpc view uninstall <name> <module>
+shpc view edit <name>""",
+        type=str,
+    )
     view.add_argument(
         "--force",
         "-f",
@@ -220,7 +196,7 @@ def get_parser():
 
     config = subparsers.add_parser(
         "config",
-        description=help.config_description,
+        description="update configuration settings. Use set or get to see or set information.",
         formatter_class=argparse.RawTextHelpFormatter,
     )
 
@@ -235,14 +211,20 @@ def get_parser():
     config.add_argument(
         "params",
         nargs="*",
-        help="parameters for config command",
+        help="""Set or get a config value, edit the config, add or remove a list variable, or create a user-specific config.
+shpc config set key value
+shpc config set key:subkey value
+shpc config get key
+shpc edit
+shpc config inituser
+shpc config add registry /tmp/registry
+shpc config remove registry /tmp/registry""",
         type=str,
     )
     # Generate markdown docs for a container registry entry
     docgen = subparsers.add_parser(
         "docgen",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.docgen_description,
+        description="Generate a markdown document for a container registry entry.",
     )
     docgen.add_argument("module_name", help="the module to generate docs for.")
     docgen.add_argument(
@@ -257,18 +239,13 @@ def get_parser():
     # Pull a nontraditional container type (e.g., github release asset)
     pull = subparsers.add_parser(
         "pull",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.pull_description,
+        description="pull a container built with singularityhub/singularity-deploy",
     )
     pull.add_argument("uri", help="the unique resource identifier to pull")
     pull.add_argument("--path", help="A custom path to pull to (defaults to $PWD)")
 
     # Test a registry entry
-    test = subparsers.add_parser(
-        "test",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.test_description,
-    )
+    test = subparsers.add_parser("test", description="test a registry entry")
     test.add_argument("module_name", help="the module to test")
     test.add_argument(
         "--template", help="a custom test.sh template to use.", default=None
@@ -299,11 +276,7 @@ def get_parser():
     )
 
     # Uninstall a module, or a specific version
-    uninstall = subparsers.add_parser(
-        "uninstall",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.uninstall_description,
-    )
+    uninstall = subparsers.add_parser("uninstall", description="uninstall a module")
     uninstall.add_argument(
         "--force",
         "-f",
@@ -313,22 +286,12 @@ def get_parser():
         action="store_true",
     )
     uninstall.add_argument(
-        "uninstall_recipe", help="module to uninstall (module/version)", nargs="?"
-    )
-    uninstall.add_argument(
-        "--all",
-        "-a",
-        dest="uninstall_all",
-        help="uninstall all recipes",
-        default=False,
-        action="store_true",
+        "uninstall_recipe", help="module to uninstall (module/version)"
     )
 
     # Update gets latest tags from OCI registries
     update = subparsers.add_parser(
-        "update",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.update_description,
+        "update", description="update a container recipe with new versions"
     )
     update.add_argument(
         "module_name", help="module to update (no version required)", nargs="?"
@@ -344,8 +307,7 @@ def get_parser():
     # sync-registry gets latest files and non-existing containers from upstream shpc
     sync = subparsers.add_parser(
         "sync-registry",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.sync_description,
+        description="get latest files and containers from an upstream shpc",
     )
     sync.add_argument(
         "module_name", help="module to add or sync from upstream", nargs="?"
@@ -396,7 +358,6 @@ def get_parser():
         inspect,
         install,
         listing,
-        remove,
         shell,
         test,
         uninstall,
@@ -419,7 +380,7 @@ def get_parser():
 
     namespace = subparsers.add_parser(
         "namespace",
-        description=help.namespace_description,
+        description="set or unset the install namespace. E.g.,:\n    shpc namespace set <namespace>\n    shpc namespace unset",
         formatter_class=argparse.RawTextHelpFormatter,
     )
     namespace.add_argument(
@@ -429,9 +390,7 @@ def get_parser():
     )
 
     show = subparsers.add_parser(
-        "show",
-        formatter_class=argparse.RawTextHelpFormatter,
-        description=help.show_description,
+        "show", description="show the config for a registry entry."
     )
     show.add_argument(
         "--versions", help="include versions", default=False, action="store_true"
@@ -447,7 +406,7 @@ def get_parser():
         dest="filter_string",
     )
 
-    for command in docgen, show, add, remove, sync:
+    for command in docgen, show, add, sync:
         command.add_argument(
             "--registry", help="GitHub repository or local path where registry lives."
         )
@@ -526,8 +485,6 @@ def run_shpc():
         from .namespace import main
     elif args.command == "pull":
         from .pull import main
-    elif args.command == "remove":
-        from .remove import main
     elif args.command == "shell":
         from .shell import main
     elif args.command == "show":
