@@ -3,7 +3,6 @@ __copyright__ = "Copyright 2021-2022, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
 import shpc.utils
-from shpc.logger import logger
 
 
 def main(args, parser, extra, subparser):
@@ -25,11 +24,9 @@ def main(args, parser, extra, subparser):
     # Update config settings on the fly
     cli.settings.update_params(args.config_params)
 
-    # It doesn't make sense to define view and no view
-    if args.view and args.no_view:
-        logger.exit("Conflicting arguments --view and --no-view, choose one.")
-
     # And do the install
-    cli.install(
-        args.install_recipe, view=args.view, disable_view=args.no_view, force=args.force
-    )
+    cli.install(args.install_recipe, force=args.force)
+    if cli.settings.default_view and not args.no_view:
+        cli.view_install(
+            cli.settings.default_view, args.install_recipe, force=args.force
+        )
