@@ -185,21 +185,7 @@ class DockerContainer(ContainerTechnology):
         # Return code
         return result["return_code"]
 
-    def install(
-        self,
-        module_path,
-        container_path,
-        name,
-        template,
-        parsed_name,
-        aliases=None,
-        url=None,
-        description=None,
-        version=None,
-        config_features=None,
-        features=None,
-        config=None,
-    ):
+    def install(self, module_path, template, module, features=None):
         """Install a general container path to a module
 
         The module_dir should be created by the calling function, and
@@ -210,50 +196,45 @@ class DockerContainer(ContainerTechnology):
         # Container features are defined in container.yaml and the settings
         # and specific values are determined by the container technology
         features = self.get_features(
-            config_features, self.settings.container_features, features
+            module.config.features, self.settings.container_features, features
         )
 
         # Ensure that the container exists
         # Do we want to clean up other versions here too?
-        manifest = self.inspect(container_path)
+        manifest = self.inspect(module.container_path)
         if not manifest:
-            sys.exit("Container %s was not found. Was it pulled?" % container_path)
+            sys.exit(
+                "Container %s was not found. Was it pulled?" % module.container_path
+            )
 
         labels = manifest[0].get("Labels", {})
 
-        # If there's a tag in the name, don't use it
-        name = name.split(":", 1)[0]
-
         # Option to create wrapper scripts for commands
-        module_dir = os.path.dirname(module_path)
+        aliases = module.config.get_aliases()
         wrapper_scripts = []
 
         # Wrapper scripts can be global (for aliases) or container specific
         if self.settings.wrapper_scripts["enabled"] is True:
             wrapper_scripts = shpc.main.wrappers.generate(
                 aliases=aliases,
-                module_dir=module_dir,
+                module_dir=module.module_dir,
                 features=features,
                 container=self,
-                image=container_path,
-                config=config,
+                image=module.container_path,
+                config=module.config,
             )
 
         # Make sure to render all values!
         out = template.render(
             settings=self.settings,
             shell=self.shell_path,
-            image=container_path,
-            description=description,
             aliases=aliases,
-            url=url,
             features=features,
-            version=version,
             labels=labels,
             creation_date=datetime.now(),
-            name=name,
-            parsed_name=parsed_name,
             command=self.command,
+            module=module,
+            parsed_name=module.config.name,
             wrapper_scripts=wrapper_scripts,
         )
         shpc.utils.write_file(module_path, out)
