@@ -3,17 +3,17 @@
 #=====
 # Created by singularity-hpc (https://github.com/singularityhub/singularity-hpc)
 # ##
-# {{ name }} on {{ creation_date }}
+# {{ module.name }} on {{ creation_date }}
 #=====
 
 proc ModulesHelp { } {
 
-    puts stderr "This module is a singularity container wrapper for {{ name }} v{{ version }}"
-    {% if description %}puts stderr "{{ description }}"{% endif %}
+    puts stderr "This module is a singularity container wrapper for {{ module.name }} v{{ module.tag.name }}"
+    {% if description %}puts stderr "{{ module.config.description }}"{% endif %}
     puts stderr ""
     puts stderr "Container (available through variable SINGULARITY_CONTAINER):"
     puts stderr ""
-    puts stderr " - {{ container_sif }}"
+    puts stderr " - {{ module.container_path }}"
     puts stderr ""
     puts stderr "Commands include:"
     puts stderr ""
@@ -54,13 +54,13 @@ if { ![info exists ::env(SINGULARITY_COMMAND_OPTS)] } {
 
 # Variables
 
-set name        {{ name }}
-set version     {{ version }}
+set name        {{ module.name }}
+set version     {{ module.tag.name }}
 set description "$name - $version"
-set containerPath {{ container_sif }}
-{% if description %}set notes       "{{ description }}"{% endif %}
-{% if url %}set homepage    "{{ url }}"{% endif %}
-set helpcommand "This module is a singularity container wrapper for {{ name }} v{{ version }}. {% if description %}{{ description }}{% endif %}"
+set containerPath {{ module.container_path }}
+{% if description %}set notes       "{{ module.config.description }}"{% endif %}
+{% if url %}set homepage    "{{ module.config.url }}"{% endif %}
+set helpcommand "This module is a singularity container wrapper for {{ module.name }} v{{ module.tag.name }}. {% if description %}{{ module.config.description }}{% endif %}"
 {% if labels %}{% for key, value in labels.items() %}set {{ key }} "{{ value }}"
 {% endfor %}{% endif %}
 
@@ -69,7 +69,7 @@ set moduleDir   [file dirname [expr { [string equal [file type ${ModulesCurrentM
 
 # conflict with modules with the same alias name
 conflict {{ parsed_name.tool }}
-{% if name != parsed_name.tool %}conflict {{ name }}{% endif %}
+{% if name != parsed_name.tool %}conflict {{ module.name }}{% endif %}
 {% if aliases %}{% for alias in aliases %}{% if alias.name != parsed_name.tool %}conflict {{ alias.name }}{% endif %}
 {% endfor %}{% endif %}
 
@@ -128,10 +128,10 @@ set-alias {|module_name|}-inspect-deffile "${inspectCmd} -d ${containerPath}"{%
 #=====
 # Module options
 #=====
-module-whatis "    Name: {{ name }}"
-module-whatis "    Version: {{ version }}"
+module-whatis "    Name: {{ module.name }}"
+module-whatis "    Version: {{ module.tag.name }}"
 {% if description %}module-whatis "    Description: ${description}"{% endif %}
-{% if url %}module-whatis "    Url: {{ url }}"{% endif %}
+{% if url %}module-whatis "    Url: {{ module.config.url }}"{% endif %}
 {% if labels %}{% for key, value in labels.items() %}module-whatis "    {{ key }}: {{ value }}"
 {% endfor %}{% endif %}
 {% if settings.singularity_module %}module load {{ settings.singularity_module }}{% endif %}
