@@ -16,7 +16,16 @@ import shpc.utils as utils
 from shpc.logger import logger
 
 # Supported variables and defaults
-supported_view_variables = {"system_modules": []}
+supported_view_variables = {"system_modules": [], "depends_on": []}
+
+
+# Shared functions
+def get_view_module_path(extension):
+    """
+    Get a view module file name based on an extension
+    """
+    modulefile_extension = ".lua" if extension == "lua" else ""
+    return ".view_module%s" % modulefile_extension
 
 
 class ViewModule:
@@ -39,12 +48,20 @@ class ViewModule:
         if not os.path.exists(view_dir):
             return
         template = self.template.load("view_module.%s" % self.module_extension)
-        view_module_file = os.path.join(view_dir, ".view_module")
+
+        # Assemble the .view_module.<extension> full path
+        view_module_file = os.path.join(
+            view_dir, get_view_module_path(self.module_extension)
+        )
         out = template.render(
-            system_modules=view_config["view"].get("system_modules", [])
+            system_modules=view_config["view"].get("system_modules", []),
+            depends_on=view_config["view"].get("depends_on", []),
         )
         utils.write_file(view_module_file, out)
-        logger.info("Wrote updated .view_module: %s" % view_module_file)
+        logger.info(
+            "Wrote updated .view_module.%s: %s"
+            % (self.module_extension, view_module_file)
+        )
 
 
 class ViewsHandler:
@@ -251,9 +268,16 @@ class ViewsHandler:
 
     def generate_view_config(self, name):
         """
-        Generate an empty view config. system_modules are not supported yet.
+        Generate an empty view config. system_modules/depends_on are not supported yet.
         """
-        cfg = {"view": {"name": name, "modules": [], "system_modules": []}}
+        cfg = {
+            "view": {
+                "name": name,
+                "modules": [],
+                "system_modules": [],
+                "depends_on": [],
+            }
+        }
         self.save_config(name, cfg)
 
 
@@ -284,6 +308,13 @@ class View:
         """
         return os.path.join(self.settings.views_base, self.name)
 
+    @property
+    def module_path(self):
+        """
+        Path to view module, with needed extension.
+        """
+        return os.path.join(self.path, get_view_module_path(self.module_extension))
+
     def reload(self):
         """
         Reload the view's config (given a change)
